@@ -10,7 +10,7 @@ use GB18030;
 
 BEGIN { $| = 1; print "1..1\n"; }
 
-print "ok 1\n";
+print "ok - 1\n";
 
 ######################### End of black magic.
 
